@@ -2,14 +2,13 @@
 
 import copy
 import logging
-from os.path import abspath, join
 import unittest
+from os.path import abspath, join
 from tempfile import gettempdir
 from typing import Type
+from urllib.parse import SplitResult, urlsplit
 
-from urllib.parse import urlsplit, SplitResult
-
-from faker import Faker  # type: ignore
+from fake import FAKER
 
 from .. import defaults
 from ..base import BaseTLDSourceParser, Registry
@@ -22,23 +21,22 @@ from ..exceptions import (
 )
 from ..helpers import project_dir
 from ..utils import (
+    BaseMozillaTLDSourceParser,
+    MozillaTLDSourceParser,
     get_fld,
     get_tld,
     get_tld_names,
     get_tld_names_container,
     is_tld,
-    MozillaTLDSourceParser,
-    BaseMozillaTLDSourceParser,
     parse_tld,
     reset_tld_names,
     update_tld_names,
     update_tld_names_cli,
 )
-
 from .base import internet_available_only, log_info
 
 __author__ = "Artur Barseghyan"
-__copyright__ = "2013-2021 Artur Barseghyan"
+__copyright__ = "2013-2025 Artur Barseghyan"
 __license__ = "MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-or-later"
 __all__ = ("TestCore",)
 
@@ -50,7 +48,6 @@ class TestCore(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.faker = Faker()
         cls.temp_dir = gettempdir()
 
     def setUp(self):
@@ -193,11 +190,11 @@ class TestCore(unittest.TestCase):
             },
             {
                 "url": "m.fr.blogspot.com.au",
-                "fld": "fr.blogspot.com.au",
-                "subdomain": "m",
-                "domain": "fr",
-                "suffix": "blogspot.com.au",
-                "tld": "blogspot.com.au",
+                "fld": "blogspot.com.au",
+                "subdomain": "m.fr",
+                "domain": "blogspot",
+                "suffix": "com.au",
+                "tld": "com.au",
                 "kwargs": {"fail_silently": True, "fix_protocol": True},
             },
             {
@@ -647,9 +644,7 @@ class TestCore(unittest.TestCase):
 
         Assert raise TldIOError on wrong `NAMES_SOURCE_URL` for `parse_tld`.
         """
-        parser_class = self.get_custom_parser_class(
-            source_url="i-do-not-exist"
-        )
+        parser_class = self.get_custom_parser_class(source_url="i-do-not-exist")
         parsed_tld = parse_tld(
             self.bad_url, fail_silently=False, parser_class=parser_class
         )
@@ -658,7 +653,7 @@ class TestCore(unittest.TestCase):
     @log_info
     def test_18_get_tld_names_and_reset_tld_names(self):
         """Test fail `get_tld_names` and repair using `reset_tld_names`."""
-        tmp_filename = join(gettempdir(), f"{self.faker.uuid4()}.dat.txt")
+        tmp_filename = join(gettempdir(), f"{FAKER.uuid()}.dat.txt")
         parser_class = self.get_custom_parser_class(
             source_url="i-do-not-exist", local_path=tmp_filename
         )
@@ -670,7 +665,7 @@ class TestCore(unittest.TestCase):
             with self.assertRaises(TldIOError):
                 get_tld_names(fail_silently=False, parser_class=parser_class)
 
-        tmp_filename = join(gettempdir(), f"{self.faker.uuid4()}.dat.txt")
+        tmp_filename = join(gettempdir(), f"{FAKER.uuid()}.dat.txt")
         parser_class_2 = self.get_custom_parser_class(
             source_url="i-do-not-exist-2", local_path=tmp_filename
         )
@@ -810,9 +805,7 @@ class TestCore(unittest.TestCase):
         """Test len of the trie nodes."""
         get_tld("http://delusionalinsanity.com")
         tld_names = get_tld_names_container()
-        self.assertGreater(
-            len(tld_names[MozillaTLDSourceParser.local_path]), 0
-        )
+        self.assertGreater(len(tld_names[MozillaTLDSourceParser.local_path]), 0)
 
     @log_info
     def test_25_get_tld_names_no_arguments(self):
@@ -842,3 +835,16 @@ class TestCore(unittest.TestCase):
                 fragment="",
             ),
         )
+
+    @log_info
+    def test_27_tld_fail_silently_pass(self):
+        """Test `get_tld` bad URL patterns that would raise exception
+        if `fail_silently` isn't `True`.
+        """
+        res = []
+        bad_url = ["https://user:password[@host.com", "https://user[@host.com"]
+        for url in bad_url:
+            _res = get_tld(url, fail_silently=True)
+            self.assertEqual(_res, None)
+            res.append(_res)
+        return res
